==> yui_editor-5.x-2.6-4.tar.gz: yui_editor/yui_editor.js <==
function render_editor(id, config) {
  if ($("#"+id).val() != null) {

    var myConfig = {
      height: config.height+'px',
      width: config.width+'px',
      dompath: config.dom,
      animate: true,
      handleSubmit: true,
      markup: config.markup,
    };

    $(document).ready(function() {
      $(".grippie").hide();
      $(".teaser-checkbox").hide();
    });

    myEditor = new YAHOO.widget.Editor(id, myConfig);
    myEditor.render();

    if (config.plaintext == 1) {
      var state = 'on';

      var Dom = YAHOO.util.Dom,
      Event = YAHOO.util.Event;

      $("#"+id).after("<button id=\"toggleEditor\">Switch to Plain Editor</button>");
      var _button = new YAHOO.widget.Button('toggleEditor');
      _button.addClass('toggleEditor');

      _button.on('click', function(ev) {
        Event.stopEvent(ev);
        if (state == 'on') {
          state = 'off';
          myEditor.saveHTML();
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'absolute');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '-9999px');
          myEditor.get('element_cont').removeClass('yui-editor-container');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'visible');
          Dom.setStyle(myEditor.get('element'), 'top', '');
          Dom.setStyle(myEditor.get('element'), 'left', '');
          Dom.setStyle(myEditor.get('element'), 'position', 'static');
          _button.set("label", 'Switch to Rich Text Editor');

          $(".grippie").show();
          $(".teaser-checkbox").show();
        }
        else {
          state = 'on';
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'static');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '0');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '0');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'hidden');
          Dom.setStyle(myEditor.get('element'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'left', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'position', 'absolute');
          myEditor.get('element_cont').addClass('yui-editor-container');
          myEditor._setDesignMode('on');
          myEditor.setEditorHTML(myEditor.get('textarea').value);
          _button.set("label", 'Switch to Plain Editor');

          $(".grippie").hide();
          $(".teaser-checkbox").hide();
        }
      });
    }
  }
};

==> yui_editor-5.x-2.6-5.tar.gz: yui_editor/yui_editor.js <==
function render_editor(id, config) {
  if ($("#"+id).val() != null) {

    var myConfig = {
      height: config.height+'px',
      width: config.width+'px',
      dompath: config.dom,
      animate: true,
     // handleSubmit: true, // Uncomment this line if your submissions are not being saved properly
      markup: config.markup,
    };

    $(document).ready(function() {
      $(".grippie").hide();
      $(".teaser-checkbox").hide();
      Dom.setStyle('toggleEditor-'+id, 'margin-top', '1.7em');
    });

    var myEditor = new YAHOO.widget.Editor(id, myConfig);
    myEditor.render();

    if (config.plaintext == 1) {
      var state = 'on';

      var Dom = YAHOO.util.Dom,
      Event = YAHOO.util.Event;

      $("#"+id).after("<button id=\"toggleEditor-"+id+"\">Switch to Plain Editor</button>");
      var _button = new YAHOO.widget.Button('toggleEditor-'+id);
      _button.addClass('toggleEditor');

      _button.on('click', function(ev) {
        Event.stopEvent(ev);
        if (state == 'on') {
          state = 'off';
          myEditor.saveHTML();
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'absolute');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '-9999px');
          myEditor.get('element_cont').removeClass('yui-editor-container');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'visible');
          Dom.setStyle(myEditor.get('element'), 'top', '');
          Dom.setStyle(myEditor.get('element'), 'left', '');
          Dom.setStyle(myEditor.get('element'), 'position', 'static');
          _button.set("label", 'Switch to Rich Text Editor');

          $(".grippie").show();
          $(".teaser-checkbox").show();
        }
        else {
          state = 'on';
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'position', 'static');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'top', '0');
          Dom.setStyle(myEditor.get('element_cont').get('firstChild'), 'left', '0');
          Dom.setStyle(myEditor.get('element'), 'visibility', 'hidden');
          Dom.setStyle(myEditor.get('element'), 'top', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'left', '-9999px');
          Dom.setStyle(myEditor.get('element'), 'position', 'absolute');
          myEditor.get('element_cont').addClass('yui-editor-container');
          myEditor._setDesignMode('on');
          myEditor.setEditorHTML(myEditor.get('textarea').value);
          _button.set("label", 'Switch to Plain Editor');

          $(".grippie").hide();
          $(".teaser-checkbox").hide();
        }
      });
    }
  }
};
